[Libreoffice-commits] core.git: scp2/source solenv/bin

2023-06-04 Thread Julien Nabet (via logerrit)
 scp2/source/calc/registryitem_calc.scp   |1 +
 scp2/source/calc/registryitem_calc.ulf   |3 +++
 solenv/bin/modules/installer/windows/property.pm |1 +
 3 files changed, 5 insertions(+)

New commits:
commit e7b1f93cd681e2d0094f5937f4132aa4e780ab9e
Author: Julien Nabet 
AuthorDate: Sun May 28 20:36:40 2023 +0200
Commit: Julien Nabet 
CommitDate: Sun Jun 4 14:31:23 2023 +0200

tdf#71096: xlr filetype not associated with Calc in Windows

Change-Id: Ifb9f74f2bd1532ebf364a3d554d303c1209393cd
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/152360
Tested-by: Jenkins
Reviewed-by: Julien Nabet 

diff --git a/scp2/source/calc/registryitem_calc.scp 
b/scp2/source/calc/registryitem_calc.scp
index 7e9dd8e8d488..b6cf9c3df5c3 100644
--- a/scp2/source/calc/registryitem_calc.scp
+++ b/scp2/source/calc/registryitem_calc.scp
@@ -1252,6 +1252,7 @@ REGISTER_PROPERTY_HANDLER_FOR_EXTENSION( stc )
 
 // registering the mso file types
 
+CONDITIONAL_REGISTER_DOC_EXTENSION( Xlr, gid_Module_Prg_Calc_MSO_Reg, xlr, 
XLR, MS_WORKS, 3, scalc.exe, open, Calc )
 CONDITIONAL_REGISTER_DOC_EXTENSION( Xls,  gid_Module_Prg_Calc_MSO_Reg, xls,  
XLS,  MS_EXCEL_WORKSHEET_OLD, 3, scalc.exe, open, Calc )
 CONDITIONAL_REGISTER_DOC_EXTENSION( Xlsx, gid_Module_Prg_Calc_MSO_Reg, xlsx, 
XLSX, MS_EXCEL_WORKSHEET, 3, scalc.exe, open, Calc )
 CONDITIONAL_REGISTER_DOC_EXTENSION( Xlsm, gid_Module_Prg_Calc_MSO_Reg, xlsm, 
XLSM, MS_EXCEL_WORKSHEET, 3, scalc.exe, open, Calc )
diff --git a/scp2/source/calc/registryitem_calc.ulf 
b/scp2/source/calc/registryitem_calc.ulf
index e12714de682d..d3f7efbb14aa 100644
--- a/scp2/source/calc/registryitem_calc.ulf
+++ b/scp2/source/calc/registryitem_calc.ulf
@@ -54,3 +54,6 @@ en-US = "Lotus Quattro Pro Spreadsheet"
 
 [STR_REG_VAL_NUMBERS_SPREADSHEET]
 en-US = "Apple Numbers"
+
+[STR_REG_VAL_MS_WORKS]
+en-US = "Microsoft Works Spreadsheet with Excel format"
diff --git a/solenv/bin/modules/installer/windows/property.pm 
b/solenv/bin/modules/installer/windows/property.pm
index 60300e49ff58..701086af3a66 100644
--- a/solenv/bin/modules/installer/windows/property.pm
+++ b/solenv/bin/modules/installer/windows/property.pm
@@ -375,6 +375,7 @@ sub set_ms_file_types_properties
 push(@{$propertyfile}, "REGISTER_DOTM" . "\t" . "0" . "\n");
 push(@{$propertyfile}, "REGISTER_RTF"  . "\t" . "0" . "\n");
 
+push(@{$propertyfile}, "REGISTER_XLR"  . "\t" . "0" . "\n");
 push(@{$propertyfile}, "REGISTER_XLS"  . "\t" . "0" . "\n");
 push(@{$propertyfile}, "REGISTER_XLSX" . "\t" . "0" . "\n");
 push(@{$propertyfile}, "REGISTER_XLSM" . "\t" . "0" . "\n");


[Libreoffice-commits] core.git: scp2/source solenv/bin

2020-08-10 Thread Mike Kaganski (via logerrit)
 scp2/source/ooo/vc_redist.scp   |4 +
 solenv/bin/modules/installer/windows/mergemodule.pm |   43 +---
 2 files changed, 34 insertions(+), 13 deletions(-)

New commits:
commit 0872e8cc87d753e6bdda9fad510a6b71cf96565f
Author: Mike Kaganski 
AuthorDate: Mon Aug 10 13:58:57 2020 +0300
Commit: Mike Kaganski 
CommitDate: Mon Aug 10 15:06:14 2020 +0200

tdf#135579: Don't uninstall vc_redist: make it permanent

Redist is a system component, that includes a varying set of DLLs,
and those DLLs are ref-counted. Installing a newer redist - i.e.
updating and increasing refcount of existing DLLs - may add new
DLLs (with initial refcount 1) in addition to the updated old DLLs
that start depending on the newly added ones; at uninstall, the
newly added DLLs may get removed because their refcount gets 0,
while other redist DLLs are kept at the updated levels - so their
dependencies now are not met, and redist gets broken.

Just mark the redist components permanent, which, according to [1],
"registers an extra system client for the component in the Windows
Installer registry settings".

A downside is that uninstall doesn't restore the original system
state ideally.

[1] https://docs.microsoft.com/en-us/windows/win32/msi/component-table

Change-Id: I3fe82bcb5844f826f5b1df622273b4e3a1e3c436
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/100426
Tested-by: Mike Kaganski 
Reviewed-by: Mike Kaganski 

diff --git a/scp2/source/ooo/vc_redist.scp b/scp2/source/ooo/vc_redist.scp
index d32758312766..75ccf2b8d09d 100644
--- a/scp2/source/ooo/vc_redist.scp
+++ b/scp2/source/ooo/vc_redist.scp
@@ -32,22 +32,26 @@
 
 #if defined(WINDOWS_X86_MERGEMODULE)
 
+/* Attributes: msidbComponentAttributesPermanent = 0x10 */
 MergeModule WINDOWS_X86_MERGEMODULE
 Feature = gm_Root;
 Name = WINDOWS_X86_MERGEMODULE_FILE;
 RootDir = "TARGETDIR";
 ComponentCondition = "VC_REDIST=1";
+Attributes_Add = "0x10";
 End
 
 #endif
 
 #if defined(WINDOWS_X64) && defined(WINDOWS_X64_MERGEMODULE)
 
+/* Attributes: msidbComponentAttributesPermanent = 0x10 */
 MergeModule WINDOWS_X64_MERGEMODULE
 Feature = gm_Root;
 Name = WINDOWS_X64_MERGEMODULE_FILE;
 RootDir = "TARGETDIR";
 ComponentCondition = "VC_REDIST=1";
+Attributes_Add = "0x10";
 End
 
 #endif
diff --git a/solenv/bin/modules/installer/windows/mergemodule.pm 
b/solenv/bin/modules/installer/windows/mergemodule.pm
index 68bb203f1053..defd59588c95 100644
--- a/solenv/bin/modules/installer/windows/mergemodule.pm
+++ b/solenv/bin/modules/installer/windows/mergemodule.pm
@@ -294,6 +294,7 @@ sub merge_mergemodules_into_msi_database
 $onemergemodulehash{'filenumber'} = $filecounter;
 $onemergemodulehash{'componentnames'} = \%componentnames;
 $onemergemodulehash{'componentcondition'} = 
$mergemodule->{'ComponentCondition'};
+$onemergemodulehash{'attributes_add'} = 
$mergemodule->{'Attributes_Add'};
 $onemergemodulehash{'cabfilename'} = $cabfilename;
 $onemergemodulehash{'feature'} = $mergemodule->{'Feature'};
 $onemergemodulehash{'rootdir'} = $mergemodule->{'RootDir'};
@@ -405,7 +406,7 @@ sub merge_mergemodules_into_msi_database
 my $workingtables = "File Media Directory FeatureComponents"; # 
required tables
 # Optional tables can be added now
 if ( $mergemodulehash->{'hasmsiassemblies'} ) { $workingtables = 
$workingtables . " MsiAssembly"; }
-if ( $mergemodulehash->{'componentcondition'} ) { $workingtables = 
$workingtables . " Component"; }
+if ( ( $mergemodulehash->{'componentcondition'} ) || ( 
$mergemodulehash->{'attributes_add'} ) ) { $workingtables = $workingtables . " 
Component"; }
 
 # Table "Feature" has to be exported, but it is not necessary to 
import it.
 if ( $^O =~ /cygwin/i ) {
@@ -462,7 +463,7 @@ sub merge_mergemodules_into_msi_database
 change_msiassembly_table($mergemodulehash, $workdir);
 }
 
-if ( $mergemodulehash->{'componentcondition'} )
+if ( ( $mergemodulehash->{'componentcondition'} ) || ( 
$mergemodulehash->{'attributes_add'} ) )
 {
 
installer::logger::include_timestamp_into_logfile("\nPerformance Info: Changing 
Component table");
 change_component_table($mergemodulehash, $workdir);
@@ -1368,7 +1369,7 @@ sub change_featurecomponent_table
 }
 
 ###
-# In the components table, the conditions of merge modules should be updated
+# In the components table, the conditions or attributes of merge modules 
should be updated
 ###
 
 sub change_component_table
@@ -1388,25 

[Libreoffice-commits] core.git: scp2/source solenv/bin

2018-12-20 Thread Libreoffice Gerrit user
 scp2/source/ooo/file_library_ooo.scp |2 +-
 scp2/source/ooo/ure.scp  |8 
 solenv/bin/modules/installer/windows/file.pm |6 +++---
 3 files changed, 8 insertions(+), 8 deletions(-)

New commits:
commit 1ae12fe4b0c610f205b9e39d74276c55a03c4fca
Author: Andrea Gelmini 
AuthorDate: Wed Dec 19 22:29:46 2018 +0100
Commit: Julien Nabet 
CommitDate: Fri Dec 21 08:48:10 2018 +0100

Fix typo in code

It passed "make check" on Linux

Change-Id: Ic8b2adeb949bfc72830667b6928147ebd053d2f0
Reviewed-on: https://gerrit.libreoffice.org/65517
Tested-by: Jenkins
Reviewed-by: Julien Nabet 

diff --git a/scp2/source/ooo/file_library_ooo.scp 
b/scp2/source/ooo/file_library_ooo.scp
index d014bf55c1a2..350b0363a763 100644
--- a/scp2/source/ooo/file_library_ooo.scp
+++ b/scp2/source/ooo/file_library_ooo.scp
@@ -63,7 +63,7 @@ End
 
 File gid_File_Lib_Policy_Cli_Oootypes_Config
 TXT_FILE_BODY;
-Styles = (PACKED, ASSIGNCOMPOMENT);
+Styles = (PACKED, ASSIGNCOMPONENT);
 Name = "cli_oootypes.config";
 Dir = gid_Brand_Dir_Program;
 AssignComponent = gid_File_Lib_Policy_Cli_Oootypes_Assembly;
diff --git a/scp2/source/ooo/ure.scp b/scp2/source/ooo/ure.scp
index a75aeb4dbb8f..09109ebc41e6 100644
--- a/scp2/source/ooo/ure.scp
+++ b/scp2/source/ooo/ure.scp
@@ -110,7 +110,7 @@ End
 
 File gid_File_Dl_Policy_Cli_Ure_Config
 TXT_FILE_BODY;
-Styles = (PACKED, ASSIGNCOMPOMENT);
+Styles = (PACKED, ASSIGNCOMPONENT);
 Name = "cli_ure.config";
 Dir = SCP2_URE_DL_DIR;
 AssignComponent = gid_File_Dl_Policy_Cli_Ure_Assembly;
@@ -144,7 +144,7 @@ End
 
 File gid_File_Dl_Policy_Cli_Basetypes_Config
 TXT_FILE_BODY;
-Styles = (PACKED, ASSIGNCOMPOMENT);
+Styles = (PACKED, ASSIGNCOMPONENT);
 Name = "cli_basetypes.config";
 Dir = SCP2_URE_DL_DIR;
 AssignComponent = gid_File_Dl_Policy_Cli_Basetypes_Assembly;
@@ -178,7 +178,7 @@ End
 
 File gid_File_Dl_Policy_Cli_Uretypes_Config
 TXT_FILE_BODY;
-Styles = (PACKED, ASSIGNCOMPOMENT);
+Styles = (PACKED, ASSIGNCOMPONENT);
 Name = "cli_uretypes.config";
 Dir = SCP2_URE_DL_DIR;
 AssignComponent = gid_File_Dl_Policy_Cli_Uretypes_Assembly;
@@ -212,7 +212,7 @@ End
 
 File gid_File_Lib_Policy_Cli_Cppuhelper_Config
 TXT_FILE_BODY;
-Styles = (PACKED, ASSIGNCOMPOMENT);
+Styles = (PACKED, ASSIGNCOMPONENT);
 Name = "cli_cppuhelper.config";
 Dir = SCP2_URE_DL_DIR;
 AssignComponent = gid_File_Lib_Policy_Cli_Cppuhelper_Assembly;
diff --git a/scp2/source/ooo/common_brand.scp b/scp2/source/ooo/common_brand.scp
index e39a65e19ef1..1eef7833f2d0 100644
--- a/scp2/source/ooo/common_brand.scp
+++ b/scp2/source/ooo/common_brand.scp
@@ -565,6 +565,15 @@ ProfileItem gid_Brand_Profileitem_Version_Updateurl
   #endif
 End
 
+ProfileItem gid_Brand_Profileitem_Version_UpdateChannel
+ProfileID = gid_Brand_Profile_Version_Ini;
+ModuleID = gid_Module_Root_Brand;
+Section = "Version";
+Order = 19;
+Key = "UpdateChannel";
+Value = "";
+End
+
 ProfileItem gid_Brand_Profileitem_Version_Updateid
 ProfileID = gid_Brand_Profile_Version_Ini;
 ModuleID = gid_Module_Root_Brand;
diff --git a/solenv/bin/modules/installer/scriptitems.pm 
b/solenv/bin/modules/installer/scriptitems.pm
index 58ca3fe7c5af..98b41f7b484a 100644
--- a/solenv/bin/modules/installer/scriptitems.pm
+++ b/solenv/bin/modules/installer/scriptitems.pm
@@ -656,6 +656,26 @@ sub replace_setup_variables
 my $updateid = $productname . "_" . $libo_version_major . "_" . 
$$languagestringref;
 $updateid =~ s/ /_/g;
 
+my $updatechannel = "";
+if ( $ENV{'UPDATE_CONFIG'} && $ENV{'UPDATE_CONFIG'} ne "")
+{
+open(CONFIG, $ENV{'UPDATE_CONFIG'});
+while ()
+{
+chomp;
+if (/^s*(\S+)=(\S+)$/)
+{
+$key = $1;
+$val = $2;
+if ($key eq "channel")
+{
+$updatechannel = $val;
+}
+}
+}
+close(CONFIG);
+}
+
 for ( my $i = 0; $i <= $#{$itemsarrayref}; $i++ )
 {
 my $oneitem = ${$itemsarrayref}[$i];
@@ -669,6 +689,7 @@ sub replace_setup_variables
 $value =~ s/\/$languagesstring/;
 $value =~ s/\/$installer::globals::build/;
 $value =~ s/\/$updateid/;
+$value =~ s/\/$updatechannel/;
 $value =~ s/\/$installer::globals::packageformat/;
 $ENV{'OOO_VENDOR'} = "" if !defined $ENV{'OOO_VENDOR'};
 $value =~ s/\/$ENV{'OOO_VENDOR'}/;
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: scp2/source solenv/bin

2014-01-09 Thread Christian Lohmaier
 scp2/source/ooo/directory_ooo_macosx.scp  |1 -
 solenv/bin/modules/installer.pm   |2 --
 solenv/bin/modules/installer/scriptitems.pm   |   15 ---
 solenv/bin/modules/installer/simplepackage.pm |   25 -
 4 files changed, 12 insertions(+), 31 deletions(-)

New commits:
commit deb39c012031b7981360665cc19dc81d3342a3ad
Author: Christian Lohmaier lohmaier+libreoff...@googlemail.com
Date:   Fri Jan 10 00:50:10 2014 +0100

fix help packaging for Mac OS X language packs

helpcontent was not packaged into the tarball that is extracted into the
user's installation directory (and thus never was installed)

simplify the packaging by getting rid of the special collect dir
(LangPackHostName) that was the cause for the problem to begin with:
LanguagePack files were collected in LangPackHostName based directory,
while HelpPack files were collected in regular directory.
And that value wasn't even used for the actual path that is delivered to
the user, so get rid of it and the associated code.

Change-Id: Iadd24382a45722bbe8d58bd97be79609fd03021b

diff --git a/scp2/source/ooo/directory_ooo_macosx.scp 
b/scp2/source/ooo/directory_ooo_macosx.scp
index 6cd14ab..0bc7bfd 100644
--- a/scp2/source/ooo/directory_ooo_macosx.scp
+++ b/scp2/source/ooo/directory_ooo_macosx.scp
@@ -22,7 +22,6 @@
 Directory gid_Dir_Bundle
 ParentID = PD_PROGDIR;
 HostName = %PRODUCTNAME.app;
-LangPackHostName = %PRODUCTNAME Language Pack.app;
 End
 
 Directory gid_Dir_Bundle_Contents
diff --git a/solenv/bin/modules/installer.pm b/solenv/bin/modules/installer.pm
index a081456..237947d 100644
--- a/solenv/bin/modules/installer.pm
+++ b/solenv/bin/modules/installer.pm
@@ -291,8 +291,6 @@ sub run {
 
 my $dirsinproductarrayref = 
installer::setupscript::get_all_items_from_script($setupscriptref, Directory);
 
-if ( $installer::globals::languagepack ) { 
installer::scriptitems::use_langpack_hostname($dirsinproductarrayref); }
-
 if ( $allvariableshashref-{'SHIFT_BASIS_INTO_BRAND_LAYER'} ) { 
$dirsinproductarrayref = 
installer::scriptitems::shift_basis_directory_parents($dirsinproductarrayref); }
 if ( $allvariableshashref-{'OFFICEDIRECTORYNAME'} ) { 
installer::scriptitems::set_officedirectory_name($dirsinproductarrayref, 
$allvariableshashref-{'OFFICEDIRECTORYNAME'}); }
 
diff --git a/solenv/bin/modules/installer/scriptitems.pm 
b/solenv/bin/modules/installer/scriptitems.pm
index 3310951..4c384ce 100644
--- a/solenv/bin/modules/installer/scriptitems.pm
+++ b/solenv/bin/modules/installer/scriptitems.pm
@@ -489,21 +489,6 @@ sub get_children
 }
 
 

-# Using different HostName for language packs
-
-
-sub use_langpack_hostname
-{
-my ($dirsref) = @_;
-
-for ( my $i = 0; $i = $#{$dirsref}; $i++ )
-{
-my $onedir = ${$dirsref}[$i];
-if (( $onedir-{'LangPackHostName'} )  ( 
$onedir-{'LangPackHostName'} ne  )) { $onedir-{'HostName'} = 
$onedir-{'LangPackHostName'}; }
-}
-}
-
-
 # Using langpack copy action for language packs
 

 
diff --git a/solenv/bin/modules/installer/simplepackage.pm 
b/solenv/bin/modules/installer/simplepackage.pm
index da58b40..118d420 100644
--- a/solenv/bin/modules/installer/simplepackage.pm
+++ b/solenv/bin/modules/installer/simplepackage.pm
@@ -289,23 +289,21 @@ sub create_package
 
 if (( $installer::globals::languagepack ) || ( 
$installer::globals::helppack ))
 {
+# LanguagePack and HelpPack files are collected in $srcfolder, 
packaged into
+# tarball.tar.bz2 and finally the Language Pack.app is assembled 
in $appfolder
 $localtempdir = $tempdir/$packagename;
-if ( $installer::globals::helppack ) { $volume_name = 
$volume_name Help Pack; }
-if ( $installer::globals::languagepack )
-{
-$volume_name = $volume_name Language Pack;
-$volume_name_classic = $volume_name_classic Language Pack;
-$volume_name_classic_app = $volume_name_classic_app Language 
Pack;
-}
+my $srcfolder = $localtempdir . / . $volume_name_classic_app . 
\.app;
+
+$volume_name .=  Language Pack;
+$volume_name_classic .=  Language Pack;
+$volume_name_classic_app .=  Language Pack;
 
-# Create tar ball named tarball.tar.bz2
-# my $appfolder = $localtempdir . / . $volume_name . \.app;
 my $appfolder = $localtempdir . / . $volume_name_classic_app . 
\.app;
 my $contentsfolder = $appfolder . /Contents;
 my $tarballname = 

[Libreoffice-commits] core.git: scp2/source solenv/bin

2013-09-10 Thread Andras Timar
 scp2/source/ooo/ure.scp  |   16 --
 solenv/bin/modules/installer/windows/file.pm |   30 ---
 2 files changed, 46 deletions(-)

New commits:
commit f5248b4f4e83d491347749cb6731a12a9509b560
Author: Andras Timar andras.ti...@collabora.com
Date:   Tue Sep 10 08:47:38 2013 +0200

CompID is not in use in scp2 files

Change-Id: I3d5b92d9890d6525b05575760a9fb4b4db65172b

diff --git a/scp2/source/ooo/ure.scp b/scp2/source/ooo/ure.scp
index 12b55a5..425b487 100644
--- a/scp2/source/ooo/ure.scp
+++ b/scp2/source/ooo/ure.scp
@@ -99,7 +99,6 @@ File gid_File_Dl_Cppu
 Dir = SCP2_URE_DL_DIR;
 Name = SCP2_URE_DL_UNO_VER(cppu, 3);
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = 36C01AC6-BB0A-4181-A8B8-50B793ADEDB7;
 End
 
 #ifdef AIX
@@ -117,7 +116,6 @@ File gid_File_Dl_Cppuhelper
 Dir = SCP2_URE_DL_DIR;
 Name = SCP2_URE_DL_UNO_COMID_VER(cppuhelper, 3);
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = D2A191E6-2023-41F5-9032-B98C50C37964;
 End
 
 #ifdef AIX
@@ -135,7 +133,6 @@ File gid_File_Dl_PurpEnvHelper
 Dir = SCP2_URE_DL_DIR;
 Name = SCP2_URE_DL_UNO_COMID_VER(purpenvhelper, 3);
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = C80146A8-A14C-44D1-AB9F-D9D8BF22277E;
 End
 
 #ifdef AIX
@@ -153,7 +150,6 @@ File gid_File_Dl_Sal
 Dir = SCP2_URE_DL_DIR;
 Name = SCP2_URE_DL_UNO_VER(sal, 3);
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = B1EF3AB6-611E-4027-958A-736583EB82E6;
 End
 
 #ifdef AIX
@@ -171,7 +167,6 @@ File gid_File_Dl_Salhelper
 Dir = SCP2_URE_DL_DIR;
 Name = SCP2_URE_DL_UNO_COMID_VER(salhelper, 3);
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = 879B80E0-F6E1-4931-8EE6-7CF867CB6AA5;
 End
 
 #ifdef AIX
@@ -274,7 +269,6 @@ File gid_File_ure_install
 Dir = FILELIST_DIR;
 Name = ure_install.filelist;
 Styles = (FILELIST, USE_INTERNAL_RIGHTS, PACKED, 
VERSION_INDEPENDENT_COMP_ID);
-// CompID = 1124A984-F905-47DC-ACEF-EDEC037F9B38;
 End
 
 
@@ -284,7 +278,6 @@ File gid_File_Dl_JrepropertiesClass
 Dir = FILELIST_DIR;
 Name = jvmfwk_jreproperties.filelist;
 Styles = (FILELIST, PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = 0C4B8DCF-18D1-47D9-8BB7-A5C1D9268016;
 End
 #endif
 
@@ -452,7 +445,6 @@ File gid_File_Dl_Jpipe
 Dir = SCP2_URE_DL_DIR;
 Name = SCP2_URE_JDL_NORMAL(jpipe);
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = B1A60DD4-51D7-4898-B899-9BD05DE2DA8F;
 End
 #endif
 
@@ -481,7 +473,6 @@ File gid_File_Dl_Libxml2
 Name = SCP2_URE_DL_VER(xml2, 2);
 #endif
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = BE6FAD97-F84C-43E3-8392-6FE2CDA04D8E;
 End
 #endif
 
@@ -529,7 +520,6 @@ File gid_File_Java_UnoloaderJar
 Dir = GID_DIR_URE_JAVA;
 Name = unoloader.jar;
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = 90F99ED3-814C-4B45-894B-D9248848CEB4;
 End
 #endif
 
@@ -539,7 +529,6 @@ File gid_File_Java_JuhJar
 Dir = GID_DIR_URE_JAVA;
 Name = juh.jar;
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = E77CC8B5-0345-4B7F-ABED-5EB9DC94E492;
 End
 #endif
 
@@ -549,7 +538,6 @@ File gid_File_Java_JurtJar
 Dir = GID_DIR_URE_JAVA;
 Name = jurt.jar;
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = EA63EDCC-9152-4560-AB7A-BFC367442E50;
 End
 #endif
 
@@ -559,7 +547,6 @@ File gid_File_Java_RidlJar
 Dir = GID_DIR_URE_JAVA;
 Name = ridl.jar;
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = 4A915C83-6BE3-41B9-BAF9-13AA27034955;
 End
 #endif
 
@@ -571,7 +558,6 @@ File gid_File_Java_JavaUnoJar
 Dir = GID_DIR_URE_JAVA;
 Name = java_uno.jar;
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = ABDC8DDA-5D2B-424C-ABD8-FD22D59658FE;
 End
 #endif
 
@@ -583,7 +569,6 @@ File gid_File_Misc_TypesRdb
 Name = udkapi.rdb;
 InstallName = types.rdb;
 Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID, SUBST_FILENAME);
-// CompID = E5086F6A-855B-4CAE-AD3A-A85A21C5AE44;
 End
 
 File gid_File_Misc_ServicesRdb
@@ -601,7 +586,6 @@ File gid_File_Misc_JavavendorsXml
 Dir = FILELIST_DIR;
 Name = jvmfwk_javavendors.filelist;
 Styles = (FILELIST, PACKED, VERSION_INDEPENDENT_COMP_ID);
-// CompID = 403FCCFE-545B-44F6-91D1-5C75F846E587;
 End
 #endif
 
diff --git a/solenv/bin/modules/installer/windows/file.pm 
b/solenv/bin/modules/installer/windows/file.pm
index 15c0af9..2bf02fc 100644
--- a/solenv/bin/modules/installer/windows/file.pm
+++ b/solenv/bin/modules/installer/windows/file.pm
@@ -924,36 +924,6 @@ sub create_files_table
 
$installer::globals::base_independent_components{$onefile-{'componentname'}} = 
1;
 }
 
-# Collecting all component ids, that are defined at files in scp 
project (should not be used anymore)
-if ( $onefile-{'CompID'} )
-{
-
diff --git a/solenv/bin/modules/installer/windows/file.pm 
b/solenv/bin/modules/installer/windows/file.pm
index 081edde6db99..d3771fae0b94 100644
--- a/solenv/bin/modules/installer/windows/file.pm
+++ b/solenv/bin/modules/installer/windows/file.pm
@@ -199,11 +199,11 @@ sub get_file_component_name
 
 my $componentname = "";
 
 # Special handling for files with ASSIGNCOMPOMENT
 
 my $styles = "";
 if ( $fileref->{'Styles'} ) { $styles = $fileref->{'Styles'}; }
-if ( $styles =~ /\bASSIGNCOMPOMENT\b/ )
+if ( $styles =~ /\bASSIGNCOMPONENT\b/ )
 {
 $componentname = 
get_component_from_assigned_file($fileref->{'AssignComponent'}, $filesref);
 }
@@ -333,7 +333,7 @@ sub get_file_component_name
 
 
 # Returning the component name for a defined file gid.
 # This is necessary for files with flag ASSIGNCOMPOMENT
 
 
 sub get_component_from_assigned_file
@@ -199,11 +199,11 @@ sub get_file_component_name
 my $componentname = "";
 
-# Special handling for files with ASSIGNCOMPOMENT
+# Special handling for files with ASSIGNCOMPONENT
 
 my $styles = "";
@@ -333,7 +333,7 @@ sub get_file_component_name
 
 # Returning the component name for a defined file gid.
-# This is necessary for files with flag ASSIGNCOMPOMENT
+# This is necessary for files with flag ASSIGNCOMPONENT
 
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: scp2/source solenv/bin

2017-08-20 Thread Markus Mohrhard
 scp2/source/ooo/common_brand.scp|9 +
 solenv/bin/modules/installer/scriptitems.pm |   21 +
 2 files changed, 30 insertions(+)

New commits:
commit ad21f8ec355dd356bdfe72c67ebf3c4c5cf3f235
Author: Markus Mohrhard 
Date:   Mon Aug 21 03:10:33 2017 +0200

updater: also write channel to version.ini outside of instdir

Change-Id: Ibb087fc9cd17e50accf78f805e0fec4f202334b1
